@@ -34,7 +34,7 @@ class ViewDiffMode(dialogmode.DialogMode):
     def is_cursor_visible(self):
         return 1   # hide cursor
 
-    def on_str(self, wnd, s):
+    def on_str(self, wnd, s, overwrite=False):
         # does nothing
         pass
 
@@ -60,8 +60,7 @@ def view_diff(curdoc, callback=None):
     diff = ''.join(difflib.unified_diff(org_lines, cur_lines,
                                         curdoc.fileinfo.fullpathname, '(buffer)'))
 
-    buf = document.Buffer()
-    doc = document.Document(buf)
+    doc = document.Document()
     doc.insert(0, diff)
 
     mode = ViewDiffMode()
